# CHANGELOG

<!-- version list -->

## v1.2.6 (2026-03-17)

### Enhancement

- Renovate config
  ([`1824923`](https://github.com/bartekmp/pharmaradar/commit/1824923cb04a1debee031cc8f62b435da94a8b67))


## v1.2.5 (2026-03-17)

### Bug Fixes

- Use fixed chrome profile path instead of randomly created temps
  ([`05316e6`](https://github.com/bartekmp/pharmaradar/commit/05316e69a450e0f24f0b50333db2791e1834aef3))


## v1.2.4 (2026-03-17)

### Bug Fixes

- **deps**: Update python dependencies
  ([`465ab13`](https://github.com/bartekmp/pharmaradar/commit/465ab1334eac1d9a870f11262cc6b9b1be99700c))


## v1.2.3 (2026-03-07)

### Bug Fixes

- **deps**: Update dependency build to v1.4.0
  ([`ec23b4c`](https://github.com/bartekmp/pharmaradar/commit/ec23b4ccba65915cc7629290a36cd74d04e4760e))

- **deps**: Update python dependencies
  ([`e8bbc8d`](https://github.com/bartekmp/pharmaradar/commit/e8bbc8d4e38af6914d1b2f6af8e472a84fab9fae))

### Chores

- **deps**: Update github artifact actions
  ([`b021a13`](https://github.com/bartekmp/pharmaradar/commit/b021a13a426a996814cb0fe74d5d709289e26fc1))


## v1.2.2 (2025-12-30)

### Chores

- **deps**: Update actions/cache action to v5
  ([`729de25`](https://github.com/bartekmp/pharmaradar/commit/729de25632c532a7371b50dd11f89f90607898cc))

- **deps**: Update dependency python-semantic-release to v10.5.3
  ([`4b104be`](https://github.com/bartekmp/pharmaradar/commit/4b104bef8315b96ab515dbd9fbc83c2a405c7393))


## v1.2.1 (2025-12-15)

### Chores

- **deps**: Update dependency black to v25.12.0
  ([`5ea2be7`](https://github.com/bartekmp/pharmaradar/commit/5ea2be7d5266d0b64df3fa54c817b31b2477baab))

- **deps**: Update dependency pytest to v9.0.2
  ([`4cb451b`](https://github.com/bartekmp/pharmaradar/commit/4cb451b85745e6e7d276487be2345f87687f3137))

- **deps**: Update dependency python to 3.14
  ([`382a443`](https://github.com/bartekmp/pharmaradar/commit/382a44399e81162801b9be260db56dae96a9d4d3))

### Enhancement

- Add 'chore' to patch_tags in pyproject.toml
  ([`b7a2282`](https://github.com/bartekmp/pharmaradar/commit/b7a2282a128eaec2cf8acf8fa016a72a5c602f3c))

- Bump version from 1.2.0 to 1.2.1
  ([`63a8eaf`](https://github.com/bartekmp/pharmaradar/commit/63a8eaf6027ab1e7ef29475e1c5f4c9f198853ca))


## v1.2.0 (2025-11-27)

### Feature

- Add renovate configuration
  ([`827900c`](https://github.com/bartekmp/pharmaradar/commit/827900cb0729eb6236ead1bcd4dfeb0da19c0a42))


## v1.1.2 (2025-09-03)

### Enhancement

- Add badges, add autopublish action
  ([`042ca5a`](https://github.com/bartekmp/pharmaradar/commit/042ca5af9b74b2252acff66084c9d0987030974f))


## v1.1.1 (2025-09-03)

### Enhancement

- Freeze build and twine packages
  ([`f8c01af`](https://github.com/bartekmp/pharmaradar/commit/f8c01afffd2be7064cb366635d7bc80d3bdd7419))


## v1.1.0 (2025-08-22)

### Feature

- Add selective fields update method
  ([`55fe226`](https://github.com/bartekmp/pharmaradar/commit/55fe226d4aef26ecd6e9efe7d6231c32ff3c4fa2))


## v1.0.2 (2025-08-20)

### Enhancement

- Update readme, remove unused file
  ([`23f66fc`](https://github.com/bartekmp/pharmaradar/commit/23f66fcd73f83f3645962eb39279e18a92f7649f))


## v1.0.1 (2025-08-19)

### Bug Fixes

- Don't run builds on tag releases
  ([`a8b9e8e`](https://github.com/bartekmp/pharmaradar/commit/a8b9e8e7ad33ae38374e866600bde332d8348fbb))

- Use right semver option
  ([`10258b5`](https://github.com/bartekmp/pharmaradar/commit/10258b5dd97b9747cd480da60de48a5350f44f1a))


## v1.0.0 (2025-08-19)

- Initial Release
